@@ -12,18 +12,20 @@
     :license: BSD, see LICENSE for more details.
 """
 
-from methods import get, getitem, post, patch, delete
+from methods import get, getitem, post, patch, delete, delete_resource
 from flask import request, abort
 from render import send_response
-from .utils import collection_link, config
+from eve.utils import resource_uri, config
 
 
 def collections_endpoint(url):
-    """ Resource endpoint handler """
+    """ Resource endpoint handler
 
-    # TODO should we support DELETE? At resource level, it would delete all
-    # resource items at once. Maybe enable this option explicitly, via a
-    # configuration setting.
+    :param url: the url that led here
+
+    .. versionadded:: 0.0.2
+        Support for DELETE resource method.
+    """
 
     resource = config.RESOURCES[url]
     response = None
@@ -31,15 +33,19 @@ def collections_endpoint(url):
         response = get(resource)
     elif request.method == 'POST':
         response = post(resource)
-    #elif request.method == 'DELETE':
-    #    pass
+    elif request.method == 'DELETE':
+        response = delete_resource(resource)
 
     if response:
         return send_response(resource, *response)
 
 
 def item_endpoint(url, **lookup):
-    """ Item endpoint handler """
+    """ Item endpoint handler
+
+    :param url: the url that led here
+    :param lookup: the query
+    """
     resource = config.RESOURCES[url]
     response = None
     if request.method == 'GET':
@@ -51,22 +57,20 @@ def item_endpoint(url, **lookup):
     elif request.method == 'DELETE':
         response = delete(resource, **lookup)
     elif request.method == 'POST':
-        # this method is enabled because we are supporting PATCH via POST with
-        # X-HTTP-Method-Override (see above), therefore we must explicitly
-        # handle this case.
+        # We are supporting PATCH via POST with X-HTTP-Method-Override (see
+        # above), therefore we must explicitly handle this case.
         abort(405)
     if response:
         return send_response(resource, *response)
 
 
 def home_endpoint():
-    """ Home/API entry point. Will provide a list of links to each resource
-    accessible.
+    """ Home/API entry point. Will provide links to each available resource
     """
     response = dict()
     links = list()
     for resource in config.DOMAIN.keys():
         links.append("<link rel='child' title='%s' href='%s' />" %
-                     (config.URLS[resource], collection_link(resource)))
+                     (config.URLS[resource], resource_uri(resource)))
     response['links'] = links
     return send_response(None, response)
