@@ -13,7 +13,7 @@
 """
 
 import re
-from ...utils import config
+from eve.utils import config
 from bson import ObjectId
 from flask import current_app as app
 from cerberus import Validator, ValidationError, SchemaError
@@ -28,7 +28,7 @@ class Validator(Validator):
                    documentation.
     :param resource: the resource name.
     """
-    def __init__(self, schema, resource):
+    def __init__(self, schema, resource=None):
         self.resource = resource
         self.object_id = None
         super(Validator, self).__init__(schema)
